//#define XERR
#include "costs.ih"

void Costs::setAge()
{
    d_base.back() = "age:";
    Parser::nonNegative(d_base, d_referenceAge);
}
